"""This file contains functionality related to game state management."""
import pygame

class Machine:
    """Game state machine class."""
    def __init__(self):
        self.current = 0
        self.previous = 0
        self.states = []

    def register(self, module):
        """Registers the state's init, update, draw, and cleanup functions."""
        self.states.append({'initialize': module.initialize,
                            'update': module.update,
                            'draw': module.draw,
                            'cleanup': module.cleanup})

    def run(self, screen, window, fill_color):
        """Runs the state given machine."""
        clock = pygame.time.Clock()
        # first run initialize!
        self.states[self.current]['initialize'](window)

        while True:
            delta_time = clock.tick(60)
            if self.current != self.previous:
                self.states[self.current]['cleanup']()
                self.states[self.current]['initialize'](window)
                self.previous = self.current

            self.states[self.current]['update'](delta_time / 1000)
            screen.fill(fill_color)
            self.states[self.current]['draw'](screen)
            pygame.display.flip()

Manager = Machine()

def change(new_state):
    """Requests a change in game state."""
    Manager.current = new_state
